==> react-native-scanbot-sdk-6.1.1.tgz: package/android/src/main/java/io/scanbot/sdk/reactnative/components/barcode_scanner_view/ScanbotBarcodeScannerViewManager.kt <==
package io.scanbot.sdk.reactnative.components.barcode_scanner_view

import com.facebook.react.bridge.ReadableArray
import com.facebook.react.bridge.ReadableMap
import com.facebook.react.common.MapBuilder
import com.facebook.react.module.annotations.ReactModule
import com.facebook.react.uimanager.SimpleViewManager
import com.facebook.react.uimanager.ThemedReactContext
import com.facebook.react.uimanager.ViewManagerDelegate
import com.facebook.react.uimanager.annotations.ReactProp
import com.facebook.react.viewmanagers.ScanbotBarcodeScannerViewManagerDelegate
import com.facebook.react.viewmanagers.ScanbotBarcodeScannerViewManagerInterface
import com.google.gson.reflect.TypeToken
import io.scanbot.sdk.reactnative.extensions.toJSON
import io.scanbot.sdk.reactnative.extensions.toPx
import io.scanbot.sdk.reactnative.models.CameraConfiguration
import io.scanbot.sdk.reactnative.models.DetectorConfig
import io.scanbot.sdk.reactnative.models.FinderInsets
import io.scanbot.sdk.reactnative.models.FinderViewConfiguration
import io.scanbot.sdk.reactnative.models.SelectedBarcodes
import io.scanbot.sdk.reactnative.models.ZoomRangeConfig
import io.scanbot.sdk.AspectRatio
import io.scanbot.sdk.barcode.BarcodeEanUpcNoExtensionsFilter
import io.scanbot.sdk.barcode.BarcodeExtensionsFilter
import io.scanbot.sdk.barcode.ui.BarcodeOverlayTextFormat
import io.scanbot.sdk.camera.CameraModule
import io.scanbot.sdk.camera.ZoomRange
import io.scanbot.sdk.ui.configuration.json.JsonBarcodesExtensionFilter
import io.scanbot.sdk_wrapper.SBWrapper
import java.util.EnumSet

@ReactModule(name = ScanbotBarcodeScannerViewManager.NAME)
class ScanbotBarcodeScannerViewManager : SimpleViewManager<ScanbotBarcodeScannerView>(),
    ScanbotBarcodeScannerViewManagerInterface<ScanbotBarcodeScannerView> {

    private val mDelegate: ViewManagerDelegate<ScanbotBarcodeScannerView>

    init {
        mDelegate = ScanbotBarcodeScannerViewManagerDelegate(this)
    }

    override fun getDelegate(): ViewManagerDelegate<ScanbotBarcodeScannerView>? {
        return mDelegate
    }

    companion object {
        const val NAME = "ScanbotBarcodeScannerView"
    }

    override fun getName(): String {
        return NAME
    }

    public override fun createViewInstance(context: ThemedReactContext): ScanbotBarcodeScannerView {
        return ScanbotBarcodeScannerView(context)
    }

    override fun getExportedCustomDirectEventTypeConstants(): Map<String, Any>? {
        return MapBuilder.of(
            BarcodeScannerResultEvent.NAME,
            MapBuilder.of("registrationName", "onBarcodeScannerResult"),
            BarcodeSelectionResultEvent.NAME,
            MapBuilder.of("registrationName", "onSelectBarcodeResult"),
        )
    }

    override fun onDropViewInstance(view: ScanbotBarcodeScannerView) {
        view.removeAttachedListeners()
        super.onDropViewInstance(view)
    }

    //region Commands

    override fun unfreezeCamera(view: ScanbotBarcodeScannerView) {
        view.barcodeScanner.viewController.startPreview()
    }

    override fun freezeCamera(view: ScanbotBarcodeScannerView) {
        view.barcodeScanner.viewController.stopPreview()
    }

    override fun addHighLightedBarcode(view: ScanbotBarcodeScannerView, barcodeItems: String?) {
        barcodeItems?.let {
            val itemType = object : TypeToken<List<SelectedBarcodes>>() {}.type

            view.selectedBarcodes = SBWrapper.gson.fromJson(it, itemType)
        }
    }

    override fun receiveCommand(
        root: ScanbotBarcodeScannerView,
        commandId: String?,
        args: ReadableArray?
    ) {
        when (commandId) {
            "freezeCamera" -> freezeCamera(root)
            "unfreezeCamera" -> unfreezeCamera(root)
            "addHighLightedBarcode" -> addHighLightedBarcode(root, args?.getString(0))
            else -> throw Error("Unrecognized command $commandId")
        }
    }

    //endregion

    @ReactProp(name = "scanningEnabled")
    override fun setScanningEnabled(view: ScanbotBarcodeScannerView, value: Boolean) {
        view.barcodeDetector.enableBarcodeScan(value)
    }

    @ReactProp(name = "flashEnabled")
    override fun setFlashEnabled(view: ScanbotBarcodeScannerView, value: Boolean) {
        view.flashState = value
        view.barcodeScanner.viewController.useFlash(value)
    }

    //region CameraModule

    @ReactProp(name = "cameraModule")
    override fun setCameraModule(view: ScanbotBarcodeScannerView, value: String?) {
        view.barcodeScanner.cameraConfiguration.setCameraModule(
            SBWrapper.gson.fromJson(value!!, CameraModule::class.java)
        )
        view.barcodeScanner.viewController.restartPreview()
    }

    @ReactProp(name = "cameraZoomRange")
    override fun setCameraZoomRange(view: ScanbotBarcodeScannerView, value: ReadableMap?) {
        val zoomRange = if (value != null) {
            val zoomRangeConfig = SBWrapper.gson.fromJson(
                value.toJSON().toString(),
                ZoomRangeConfig::class.java
            )
            ZoomRange(zoomRangeConfig.maxZoom, zoomRangeConfig.minZoom)
        } else {
            CameraConfiguration.DEFAULT_ZOOM_RANGE
        }

        view.barcodeScanner.cameraConfiguration.setPhysicalZoomRange(zoomRange)
    }

    @ReactProp(name = "minFocusDistanceLock")
    override fun setMinFocusDistanceLock(view: ScanbotBarcodeScannerView, value: Boolean) {
        view.barcodeScanner.cameraConfiguration.lockMinFocusDistance(value)
        view.barcodeScanner.viewController.restartPreview()
    }

    @ReactProp(name = "cameraZoomFactor")
    override fun setCameraZoomFactor(view: ScanbotBarcodeScannerView, value: Float) {
        view.barcodeScanner.cameraConfiguration.setPhysicalZoomRatio(value)
    }

    //endregion

    @ReactProp(name = "detectorConfig")
    override fun setDetectorConfig(view: ScanbotBarcodeScannerView, value: ReadableMap?) {
        val config = if (value != null) {
            SBWrapper.gson.fromJson(
                value.toJSON().toString(),
                DetectorConfig::class.java
            )
        } else {
            DetectorConfig()
        }

        view.barcodeDetector.modifyConfig {
            this.setBarcodeFormats(config.barcodeFormats!!)
            this.setAcceptedDocumentFormats(config.acceptedDocumentFormats!!)
            this.setEngineMode(config.engineMode!!)
            this.modifyAdditionalConfig {
                this.setLowPowerMode(config.lowPowerMode!!)
                this.setGs1HandlingMode(config.gs1HandlingMode!!)
                this.setMinimumTextLength(config.minimumTextLength!!)
                this.setMaximumTextLength(config.maximumTextLength!!)
                this.setMinimum1DQuietZoneSize(config.minimum1DBarcodesQuietZone!!)
                this.setStripCheckDigits(config.stripCheckDigits!!)
                this.setMsiPlesseyChecksumAlgorithms(
                    EnumSet.of(config.msiPlesseyChecksumAlgorithm!!)
                )
            }
        }

        view.barcodeScanner.viewController.setBarcodeFilter(
            when (config.barcodesExtensionFilter!!) {
                JsonBarcodesExtensionFilter.NO_FILTER -> null
                JsonBarcodesExtensionFilter.ONLY_WITH_EXTENSIONS -> BarcodeExtensionsFilter()
                JsonBarcodesExtensionFilter.ONLY_WITHOUT_EXTENSIONS -> BarcodeEanUpcNoExtensionsFilter()
            }
        )
    }

    //region FinderConfig

    @ReactProp(name = "finderRequiredAspectRatios")
    override fun setFinderRequiredAspectRatios(
        view: ScanbotBarcodeScannerView,
        value: ReadableMap?
    ) {
        val aspectRatios = if (value != null) {
            listOf(
                SBWrapper.gson.fromJson(
                    value.toJSON().toString(),
                    AspectRatio::class.java
                )
            )
        } else {
            FinderViewConfiguration.DEFAULT_ASPECT_RATIO
        }

        view.barcodeScanner.finderViewController.setRequiredAspectRatios(aspectRatios)
    }

    @ReactProp(name = "finderInset")
    override fun setFinderInset(view: ScanbotBarcodeScannerView, value: ReadableMap?) {
        val insets = if (value != null) {
            SBWrapper.gson.fromJson(
                value.toJSON().toString(),
                FinderInsets::class.java
            )
        } else {
            FinderViewConfiguration.DEFAULT_FINDER_INSETS
        }

        view.barcodeScanner.finderViewController.setFinderInset(
            left = insets.left.toPx(view.resources),
            right = insets.right.toPx(view.resources),
            top = insets.top.toPx(view.resources),
            bottom = insets.bottom.toPx(view.resources)
        )
    }

    @ReactProp(name = "finderEnabled")
    override fun setFinderEnabled(view: ScanbotBarcodeScannerView, value: Boolean) {
        view.barcodeScanner.finderViewController.setFinderEnabled(value)
    }

    @ReactProp(name = "finderStrokeWidth")
    override fun setFinderStrokeWidth(view: ScanbotBarcodeScannerView, value: Int) {
        view.barcodeScanner.finderViewController.setStrokeWidth(value.toPx(view.resources))
    }

    @ReactProp(name = "finderStrokeColor", customType = "Color")
    override fun setFinderStrokeColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.barcodeScanner.finderViewController.setStrokeColor(
            value ?: FinderViewConfiguration.DEFAULT_STROKE_COLOR
        )
    }

    @ReactProp(name = "finderOverlayColor", customType = "Color")
    override fun setFinderOverlayColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.barcodeScanner.finderViewController.setOverlayColor(
            value ?: FinderViewConfiguration.DEFAULT_OVERLAY_COLOR
        )
    }

    @ReactProp(name = "finderMinPadding")
    override fun setFinderMinPadding(view: ScanbotBarcodeScannerView, value: Int) {
        view.barcodeScanner.finderViewController.setFinderMinPadding(value)
    }

    //endregion

    //region SelectionOverlay

    @ReactProp(name = "overlayStrokeColor", customType = "Color")
    override fun setOverlayStrokeColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.polygonStyle.strokeColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayHighlightedStrokeColor", customType = "Color")
    override fun setOverlayHighlightedStrokeColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.polygonStyle.strokeHighlightedColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayPolygonColor", customType = "Color")
    override fun setOverlayPolygonColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.polygonStyle.fillColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayHighlightedPolygonColor", customType = "Color")
    override fun setOverlayHighlightedPolygonColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.polygonStyle.fillHighlightedColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayTextColor", customType = "Color")
    override fun setOverlayTextColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.textStyle.textColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayHighlightedTextColor", customType = "Color")
    override fun setOverlayHighlightedTextColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.textStyle.textHighlightedColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayTextContainerColor", customType = "Color")
    override fun setOverlayTextContainerColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.textStyle.textContainerColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayHighlightedTextContainerColor", customType = "Color")
    override fun setOverlayHighlightedTextContainerColor(
        view: ScanbotBarcodeScannerView,
        value: Int?
    ) {
        view.textStyle.textContainerHighlightedColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayTextFormat")
    override fun setOverlayTextFormat(view: ScanbotBarcodeScannerView, value: String?) {
        view.textStyle.textFormat =
            value?.let { SBWrapper.gson.fromJson(it, BarcodeOverlayTextFormat::class.java) }
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayEnabled")
    override fun setOverlayEnabled(view: ScanbotBarcodeScannerView, value: Boolean) {
        view.barcodeScanner.selectionOverlayController.setEnabled(value)
    }

    // endregion
}

==> react-native-scanbot-sdk-6.2.1.tgz: package/android/src/main/java/io/scanbot/sdk/reactnative/components/barcode_scanner_view/ScanbotBarcodeScannerViewManager.kt <==
package io.scanbot.sdk.reactnative.components.barcode_scanner_view

import com.facebook.react.bridge.ReadableArray
import com.facebook.react.bridge.ReadableMap
import com.facebook.react.common.MapBuilder
import com.facebook.react.module.annotations.ReactModule
import com.facebook.react.uimanager.SimpleViewManager
import com.facebook.react.uimanager.ThemedReactContext
import com.facebook.react.uimanager.ViewManagerDelegate
import com.facebook.react.uimanager.annotations.ReactProp
import com.facebook.react.viewmanagers.ScanbotBarcodeScannerViewManagerDelegate
import com.facebook.react.viewmanagers.ScanbotBarcodeScannerViewManagerInterface
import io.scanbot.sdk.AspectRatio
import io.scanbot.sdk.barcode.BarcodeEanUpcNoExtensionsFilter
import io.scanbot.sdk.barcode.BarcodeExtensionsFilter
import io.scanbot.sdk.barcode.ui.BarcodeOverlayTextFormat
import io.scanbot.sdk.camera.CameraModule
import io.scanbot.sdk.camera.ZoomRange
import io.scanbot.sdk.reactnative.extensions.toJSON
import io.scanbot.sdk.reactnative.extensions.toPx
import io.scanbot.sdk.reactnative.models.BarcodeItemOverlayViewConfig
import io.scanbot.sdk.reactnative.models.CameraConfiguration
import io.scanbot.sdk.reactnative.models.DetectorConfig
import io.scanbot.sdk.reactnative.models.FinderInsets
import io.scanbot.sdk.reactnative.models.FinderViewConfiguration
import io.scanbot.sdk.reactnative.models.ZoomRangeConfig
import io.scanbot.sdk.ui.configuration.json.JsonBarcodesExtensionFilter
import io.scanbot.sdk_wrapper.SBWrapper
import java.util.EnumSet

@ReactModule(name = ScanbotBarcodeScannerViewManager.NAME)
class ScanbotBarcodeScannerViewManager : SimpleViewManager<ScanbotBarcodeScannerView>(),
    ScanbotBarcodeScannerViewManagerInterface<ScanbotBarcodeScannerView> {

    private val mDelegate: ViewManagerDelegate<ScanbotBarcodeScannerView> =
        ScanbotBarcodeScannerViewManagerDelegate(this)

    override fun getDelegate(): ViewManagerDelegate<ScanbotBarcodeScannerView>? {
        return mDelegate
    }

    companion object {
        const val NAME = "ScanbotBarcodeScannerView"
    }

    override fun getName(): String {
        return NAME
    }

    public override fun createViewInstance(context: ThemedReactContext): ScanbotBarcodeScannerView {
        return ScanbotBarcodeScannerView(context)
    }

    @Suppress("DEPRECATION")
    override fun getExportedCustomDirectEventTypeConstants(): Map<String, Any>? {
        return MapBuilder.of(
            BarcodeScannerResultEvent.NAME,
            MapBuilder.of("registrationName", "onBarcodeScannerResult"),
            BarcodeSelectionResultEvent.NAME,
            MapBuilder.of("registrationName", "onSelectBarcodeResult"),
        )
    }

    override fun onDropViewInstance(view: ScanbotBarcodeScannerView) {
        view.removeAttachedListeners()
        super.onDropViewInstance(view)
    }

    //region Commands

    override fun unfreezeCamera(view: ScanbotBarcodeScannerView) {
        view.barcodeScanner.viewController.startPreview()
    }

    override fun freezeCamera(view: ScanbotBarcodeScannerView) {
        view.barcodeScanner.viewController.stopPreview()
    }

    override fun bindBarcodeItemOverlayView(
        view: ScanbotBarcodeScannerView, barcodeItemUuid: String, bindingConfig: String
    ) {
        val barcodeItemOverlayViewConfig =
            SBWrapper.gson.fromJson(bindingConfig, BarcodeItemOverlayViewConfig::class.java)

        view.updateBarcodeItemOverlayViewBinder(barcodeItemUuid, barcodeItemOverlayViewConfig)
        view.setOverlayAppearance()
    }

    @Suppress("UNNECESSARY_NOT_NULL_ASSERTION")
    override fun receiveCommand(
        root: ScanbotBarcodeScannerView,
        commandId: String?,
        args: ReadableArray?
    ) {
        when (commandId) {
            "freezeCamera" -> freezeCamera(root)
            "unfreezeCamera" -> unfreezeCamera(root)
            "bindBarcodeItemOverlayView" -> args?.let {
                bindBarcodeItemOverlayView(
                    root, it.getString(0)!!, it.getString(1)!!
                )
            }

            else -> throw Error("Unrecognized command $commandId")
        }
    }

    //endregion

    @ReactProp(name = "scanningEnabled")
    override fun setScanningEnabled(view: ScanbotBarcodeScannerView, value: Boolean) {
        view.barcodeDetector.enableBarcodeScan(value)
    }

    @ReactProp(name = "flashEnabled")
    override fun setFlashEnabled(view: ScanbotBarcodeScannerView, value: Boolean) {
        view.flashState = value
        view.barcodeScanner.viewController.useFlash(value)
    }

    //region CameraModule

    @ReactProp(name = "cameraModule")
    override fun setCameraModule(view: ScanbotBarcodeScannerView, value: String?) {
        view.barcodeScanner.cameraConfiguration.setCameraModule(
            SBWrapper.gson.fromJson(value!!, CameraModule::class.java)
        )
        view.barcodeScanner.viewController.restartPreview()
    }

    @ReactProp(name = "cameraZoomRange")
    override fun setCameraZoomRange(view: ScanbotBarcodeScannerView, value: ReadableMap?) {
        val zoomRange = if (value != null) {
            val zoomRangeConfig = SBWrapper.gson.fromJson(
                value.toJSON().toString(),
                ZoomRangeConfig::class.java
            )
            ZoomRange(zoomRangeConfig.maxZoom, zoomRangeConfig.minZoom)
        } else {
            CameraConfiguration.DEFAULT_ZOOM_RANGE
        }

        view.barcodeScanner.cameraConfiguration.setPhysicalZoomRange(zoomRange)
    }

    @ReactProp(name = "minFocusDistanceLock")
    override fun setMinFocusDistanceLock(view: ScanbotBarcodeScannerView, value: Boolean) {
        view.barcodeScanner.cameraConfiguration.lockMinFocusDistance(value)
        view.barcodeScanner.viewController.restartPreview()
    }

    @ReactProp(name = "cameraZoomFactor")
    override fun setCameraZoomFactor(view: ScanbotBarcodeScannerView, value: Float) {
        view.barcodeScanner.cameraConfiguration.setPhysicalZoomRatio(value)
    }

    //endregion

    @ReactProp(name = "detectorConfig")
    override fun setDetectorConfig(view: ScanbotBarcodeScannerView, value: ReadableMap?) {
        val config = if (value != null) {
            SBWrapper.gson.fromJson(
                value.toJSON().toString(),
                DetectorConfig::class.java
            )
        } else {
            DetectorConfig()
        }

        view.barcodeDetector.modifyConfig {
            this.setBarcodeFormats(config.barcodeFormats!!)
            this.setAcceptedDocumentFormats(config.acceptedDocumentFormats!!)
            this.setEngineMode(config.engineMode!!)
            this.modifyAdditionalConfig {
                this.setLowPowerMode(config.lowPowerMode!!)
                this.setGs1HandlingMode(config.gs1HandlingMode!!)
                this.setMinimumTextLength(config.minimumTextLength!!)
                this.setMaximumTextLength(config.maximumTextLength!!)
                this.setMinimum1DQuietZoneSize(config.minimum1DBarcodesQuietZone!!)
                this.setStripCheckDigits(config.stripCheckDigits!!)
                this.setMsiPlesseyChecksumAlgorithms(
                    EnumSet.of(config.msiPlesseyChecksumAlgorithm!!)
                )
            }
        }

        view.barcodeScanner.viewController.setBarcodeFilter(
            when (config.barcodesExtensionFilter!!) {
                JsonBarcodesExtensionFilter.NO_FILTER -> null
                JsonBarcodesExtensionFilter.ONLY_WITH_EXTENSIONS -> BarcodeExtensionsFilter()
                JsonBarcodesExtensionFilter.ONLY_WITHOUT_EXTENSIONS -> BarcodeEanUpcNoExtensionsFilter()
            }
        )
    }

    //region FinderConfig

    @ReactProp(name = "finderRequiredAspectRatios")
    override fun setFinderRequiredAspectRatios(
        view: ScanbotBarcodeScannerView,
        value: ReadableMap?
    ) {
        val aspectRatios = if (value != null) {
            listOf(
                SBWrapper.gson.fromJson(
                    value.toJSON().toString(),
                    AspectRatio::class.java
                )
            )
        } else {
            FinderViewConfiguration.DEFAULT_ASPECT_RATIO
        }

        view.barcodeScanner.finderViewController.setRequiredAspectRatios(aspectRatios)
    }

    @ReactProp(name = "finderInset")
    override fun setFinderInset(view: ScanbotBarcodeScannerView, value: ReadableMap?) {
        val insets = if (value != null) {
            SBWrapper.gson.fromJson(
                value.toJSON().toString(),
                FinderInsets::class.java
            )
        } else {
            FinderViewConfiguration.DEFAULT_FINDER_INSETS
        }

        view.barcodeScanner.finderViewController.setFinderInset(
            left = insets.left.toPx(view.resources),
            right = insets.right.toPx(view.resources),
            top = insets.top.toPx(view.resources),
            bottom = insets.bottom.toPx(view.resources)
        )
    }

    @ReactProp(name = "finderEnabled")
    override fun setFinderEnabled(view: ScanbotBarcodeScannerView, value: Boolean) {
        view.barcodeScanner.finderViewController.setFinderEnabled(value)
    }

    @ReactProp(name = "finderStrokeWidth")
    override fun setFinderStrokeWidth(view: ScanbotBarcodeScannerView, value: Int) {
        view.barcodeScanner.finderViewController.setStrokeWidth(value.toPx(view.resources))
    }

    @ReactProp(name = "finderStrokeColor", customType = "Color")
    override fun setFinderStrokeColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.barcodeScanner.finderViewController.setStrokeColor(
            value ?: FinderViewConfiguration.DEFAULT_STROKE_COLOR
        )
    }

    @ReactProp(name = "finderOverlayColor", customType = "Color")
    override fun setFinderOverlayColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.barcodeScanner.finderViewController.setOverlayColor(
            value ?: FinderViewConfiguration.DEFAULT_OVERLAY_COLOR
        )
    }

    @ReactProp(name = "finderMinPadding")
    override fun setFinderMinPadding(view: ScanbotBarcodeScannerView, value: Int) {
        view.barcodeScanner.finderViewController.setFinderMinPadding(value)
    }

    //endregion

    //region SelectionOverlay

    @ReactProp(name = "overlayStrokeColor", customType = "Color")
    override fun setOverlayStrokeColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.polygonStyle.strokeColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayPolygonColor", customType = "Color")
    override fun setOverlayPolygonColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.polygonStyle.fillColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayTextColor", customType = "Color")
    override fun setOverlayTextColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.textStyle.textColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayTextContainerColor", customType = "Color")
    override fun setOverlayTextContainerColor(view: ScanbotBarcodeScannerView, value: Int?) {
        view.textStyle.textContainerColor = value
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayTextFormat")
    override fun setOverlayTextFormat(view: ScanbotBarcodeScannerView, value: String?) {
        view.textStyle.textFormat =
            value?.let { SBWrapper.gson.fromJson(it, BarcodeOverlayTextFormat::class.java) }
        view.setOverlayAppearance()
    }

    @ReactProp(name = "overlayEnabled")
    override fun setOverlayEnabled(view: ScanbotBarcodeScannerView, value: Boolean) {
        view.barcodeScanner.selectionOverlayController.setEnabled(value)
    }

    @ReactProp(name = "overlayLoadingTextValue")
    override fun setOverlayLoadingTextValue(view: ScanbotBarcodeScannerView?, value: String?) {
        BarcodeItemOverlayViewConfig.LOADING_TEXT = value
    }

    @ReactProp(name = "overlayBarcodeItemOverlayViewBinder")
    override fun setOverlayBarcodeItemOverlayViewBinder(
        view: ScanbotBarcodeScannerView, value: Boolean
    ) {
        if (value) {
            view.setBarcodeItemOverlayViewBinderCallback()
        }
    }

    // endregion
}
